class AS7RID_FAIL(Exception):
    pass


class INVALID_PROXY_TYPE(Exception):
    pass


class USERID_REQUIRED_FOR_BATCH(Exception):
    pass


class INVALID_ARG_IN_GET_BATCH_JOB(Exception):
    pass


class UNEXPECTED_ARG(Exception):
    pass


class URL_IS_DIFFERENT_FROM_BASE_MARKET(Exception):
    pass
